django-project-portfolio |version|
==================================

``django-project-portfolio`` is a simple `Django
<https://www.djangoproject.com/>`_ for displaying information about
software projects you maintain.


Documentation contents
----------------------

.. toctree::
   :maxdepth: 1

   install
   models
   views